@@ -1,6 +1,6 @@
 #' Calculate animal ages.
 #'
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #' Part of Pedigree Curation
 #'
@@ -10,22 +10,20 @@
 #' @return A numeric vector (\code{NA} allowed) indicating age in decimal years
 #' from "birth" to "exit" or the current date if "exit" is NA.
 #'
-#' @examples
-#' \donttest{
-#' library(nprcgenekeepr)
-#' qcPed <- nprcgenekeepr::qcPed
-#' originalAge <- qcPed$age ## ages calculated at time of data collection
-#' currentAge <- calcAge(qcPed$birth, qcPed$exit) ## assumes no changes in
-#'                                                ## colony
-#' }
-#'
 #' @param birth Date vector of birth dates
 #' @param exit Date vector of exit dates.
 #'
 #' @export
+#' @examples
+#' library(nprcgenekeepr)
+#' qcPed <- nprcgenekeepr::qcPed
+#' originalAge <- qcPed$age ## ages calculated at time of data collection
+#' currentAge <- calcAge(qcPed$birth, qcPed$exit) ## assumes no changes in
+#' ## colony
 calcAge <- function(birth, exit) {
-  if (length(birth) == 0)
+  if (length(birth) == 0L) {
     return(birth)
+  }
   exit[is.na(exit)] <- Sys.Date()
-  return(round( (as.double(exit - birth) / 365.25), 1))
+  round((as.double(exit - birth) / 365.25), 1L)
 }
