@@ -1,6 +1,6 @@
 #' Filters kinship to remove rows with kinship values less than the specified
 #' threshold
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #'
 #' Part of Group Formation
@@ -10,17 +10,6 @@
 #' @return The kinship matrix with all kinship relationships below the
 #' threshold value removed.
 #'
-#' @examples
-#' \donttest{
-#' library(nprcgenekeepr)
-#' ped <- nprcgenekeepr::lacy1989Ped
-#' ped$gen <- findGeneration(ped$id, ped$sire, ped$dam)
-#' kmat <- kinship(ped$id, ped$sire, ped$dam, ped$gen)
-#' kin <- kinMatrix2LongForm(kmat, rm.dups = FALSE)
-#' kinFiltered_0.3 <- filterThreshold(kin, threshold = 0.3)
-#' kinFiltered_0.1 <- filterThreshold(kin, threshold = 0.1)
-#' }
-#'
 #' @param kin a dataframe with columns \code{id1}, \code{id2}, and
 #' \code{kinship}. This is the kinship data reformatted from a matrix,
 #' to a long-format table.
@@ -28,9 +17,18 @@
 #' considered in group formation. Pairwise kinship below this level will be
 #' ignored.
 #' @export
+#' @examples
+#' library(nprcgenekeepr)
+#' ped <- nprcgenekeepr::lacy1989Ped
+#' ped$gen <- findGeneration(ped$id, ped$sire, ped$dam)
+#' kmat <- kinship(ped$id, ped$sire, ped$dam, ped$gen)
+#' kin <- kinMatrix2LongForm(kmat, removeDups = FALSE)
+#' kinFiltered_0.3 <- filterThreshold(kin, threshold = 0.3)
+#' kinFiltered_0.1 <- filterThreshold(kin, threshold = 0.1)
 filterThreshold <- function(kin, threshold = 0.015625) {
   kin <- kin[kin$kinship >= threshold, ]
-  if (nrow(kin) > 0)
+  if (nrow(kin) > 0L) {
     rownames(kin) <- seq_len(nrow(kin))
+  }
   return(kin)
 }
