@@ -1,6 +1,6 @@
 #' Get the superset of columns that can be in a pedigree file.
 #'
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #' Part of Genetic Value Functions
 #'
@@ -8,13 +8,12 @@
 #'
 #' @return Superset of columns that can be in a pedigree file.
 #'
-#' @examples
-#' \donttest{
-#' getIncludeColumns()
-#' }
-#'
 #' @export
+#' @examples
+#' getIncludeColumns()
 getIncludeColumns <- function() {
-  c("id", "sex", "age", "birth", "exit", "population", "condition", "origin",
-    "first_name", "second_name")
+  c(
+    "id", "sex", "age", "birth", "exit", "population", "condition", "origin",
+    "first_name", "second_name"
+  )
 }
