@@ -6,18 +6,18 @@
 #' @return A character vector of potential sire Ids
 #'
 #' @param ids character vector of IDs of the animals
+#' @param ped dataframe that is the `Pedigree`. It contains pedigree
+#' information including the IDs listed in \code{candidates}.
 #' @param minAge integer value indicating the minimum age to consider in group
 #' formation. Pairwise kinships involving an animal of this age or younger will
 #'  be ignored. Default is 1 year.
-#' @param ped dataframe that is the `Pedigree`. It contains pedigree
-#' information including the IDs listed in \code{candidates}.
 #' @export
 #' @examples
 #' library(nprcgenekeepr)
 #' ped <- nprcgenekeepr::pedWithGenotype
 #' ids <- nprcgenekeepr::qcBreeders
-#' getPotentialSires(ids, minAge = 1L, ped)
-getPotentialSires <- function(ids, minAge = 1L, ped) {
+#' getPotentialSires(ids, ped, minAge = 1L)
+getPotentialSires <- function(ids, ped, minAge = 1L) {
   ped <- ped[!is.na(ped$birth), ]
   ped$id[ped$id %in% ids & ped$sex == "M" & getCurrentAge(ped$birth) >= minAge &
     !is.na(ped$birth)]
