@@ -32,13 +32,13 @@ hasGenotype <- function(genotype) {
     FALSE # "Genotype must have 'id' as a column.")
   } else if (!any(tolower(cols) == "first")) {
     FALSE # "Genotype must have a column named 'first'
-  } else if (!any(tolower(cols) == "second")) {
+  } else if (!any(tolower(cols) == "second")) { # nolint: if_not_else_linter
     FALSE # "Genotype  must have a column named 'second'
   } else {
     if (!any(is.numeric(genotype$first))) {
       FALSE # genotype representation (indirection) should be integer
       # at this point
-    } else if (!any(is.numeric(genotype$second))) {
+    } else if (!any(is.numeric(genotype$second))) { # nolint: if_not_else_linter
       FALSE # genotype representation (indirection) should be integer
     } else {
       TRUE
