@@ -1,6 +1,6 @@
 #' Update or add the "group" field of a Pedigree.
 #'
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #' Part of the pedigree filtering toolset
 #'
@@ -12,8 +12,9 @@
 #' information. The \code{id} column is required.
 #' @param ids character vector of IDs to be flagged as part of the group under
 #' consideration.
+#' @noRd
 resetGroup <- function(ped, ids) {
   ped$group <- FALSE
   ped$group[ped$id %in% ids] <- TRUE
-  return(ped)
+  ped
 }
