@@ -12,7 +12,8 @@ uitpGeneticValueAnalysis <-
           "margin-left:3px; margin-top: 3px; margin-bottom: 3px;",
           "border-radius: 25px; box-shadow: 0 0 5px 2px #888"
         ),
-        includeHTML("../extdata/ui_guidance/genetic_value.html")
+        includeHTML(file.path("..", "extdata", "ui_guidance",
+                              "genetic_value.html"))
       ),
 
       # Main Panel
