@@ -1,4 +1,4 @@
-#' Copyright(c) 2017-2020 R. Mark Sharp
+#' Copyright(c) 2017-2024 R. Mark Sharp
 #' This file is part of nprcgenekeepr
 context("countFirstOrder")
 library(testthat)
@@ -9,11 +9,10 @@ countIds <- countFirstOrder(ped, ids)
 count <- countFirstOrder(ped, NULL)
 
 test_that("countFirstOrder makes correct transformations", {
-  expect_equal(countIds$id[countIds$id %in% count$id], countIds$id)
+  expect_identical(countIds$id[countIds$id %in% count$id], countIds$id)
   expect_true(all(count$id[count$id %in% countIds$id] %in% countIds$id))
-  expect_equal(count$parents, c(0, 0, 2, 2, 0, 2, 2))
-  expect_equal(count$offspring, c(2, 2, 0, 2, 2, 0, 0))
-  expect_equal(count$siblings, c(0, 0, 1, 1, 0, 1, 1))
-  expect_equal(count$total, c(2, 2, 3, 5, 2, 3, 3))
-
+  expect_identical(count$parents, c(0L, 0L, 2L, 2L, 0L, 2L, 2L))
+  expect_identical(count$offspring, c(2L, 2L, 0L, 2L, 2L, 0L, 0L))
+  expect_identical(count$siblings, c(0L, 0L, 1L, 1L, 0L, 1L, 1L))
+  expect_identical(count$total, c(2L, 2L, 3L, 5L, 2L, 3L, 3L))
 })
