@@ -1,4 +1,4 @@
-#' Copyright(c) 2017-2020 R. Mark Sharp
+#' Copyright(c) 2017-2024 R. Mark Sharp
 # This file is part of nprcgenekeepr
 context("resetGroup")
 library(testthat)
@@ -6,9 +6,9 @@ data("smallPed")
 ped <- smallPed
 test_that("resetGroup correctly returns correct IDs", {
   ped1 <- resetGroup(ped = ped, ids = NULL)
-  expect_true(all(!ped1$group))
+  expect_true(!any(ped1$group))
   ped1 <- resetGroup(ped = ped, ids = c("A", "B", "I"))
   expect_true(all(ped1$group[ped1$id %in%
-                                    c("A", "B", "I")]))
-  expect_true(length(setdiff(ped1$id[ped1$group], c("A", "B", "I"))) == 0)
+    c("A", "B", "I")]))
+  expect_length(setdiff(ped1$id[ped1$group], c("A", "B", "I")), 0L)
 })
